/*****************************************************************************
Copyright (c) 2011 SmartVault, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 ******************************************************************************/
package com.smartvault.oauth;

import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.Signature;
import java.security.SignatureException;

public class SelfTokenEncoder {
    private static final String SHA256WITH_RSA = "SHA256withRSA"; //$NON-NLS-1$

	private static final String SCHEME = "SLF00"; //$NON-NLS-1$

    private String nonce;

    private String clientId;

    public String generate(final PrivateKey key)
            throws NoSuchAlgorithmException, InvalidKeyException,
            SignatureException, Exception {
        final Signature rsa = Signature.getInstance(SHA256WITH_RSA);
        rsa.initSign(key);

        final byte[] tmp = createBasicToken();

        rsa.update(tmp);
        final byte[] sig = rsa.sign();

        final byte[] c = combine(tmp, sig);

        return Base64.encode(c);
    }

    private byte[] combine(final byte[] a, final byte[] b) {
        final byte[] c = new byte[a.length + b.length];
        System.arraycopy(a, 0, c, 0, a.length);
        System.arraycopy(b, 0, c, a.length, b.length);
        return c;
    }

    private byte[] createBasicToken() throws Exception {
        final int rawTokenSize =
            1 + this.clientId.length() + 1 + this.nonce.length() + SCHEME.length();

        final ByteWriter writer = new ByteWriter(new byte[rawTokenSize]);
        writer.write(SCHEME);
        writer.writeStrLen(this.clientId);
        writer.writeStrLen(this.nonce);
        return writer.getBuffer();
    }

    public SelfTokenEncoder(final String clientId, final String nonce) {
        this.clientId = clientId;
        this.nonce = nonce;
    }
}
