/*****************************************************************************
Copyright (c) 2011 SmartVault, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 ******************************************************************************/
package com.smartvault.rest;

import java.security.*;

/**
 * This class provides all of the configuration information used by a client 
 * program to interact in an autonomous fashion with the REST API. This class
 * is constructed as a prelude to create the Authentication object. This 
 * step should only be performed on a trusted server.
 * 
 * @see Authentication
 *
 */
public class ServerCfg extends ServerCfgBase {
	private String clientId;
	private PrivateKey privateKey;

	/**
	 * Constructor
	 * 
	 * uses default path to REST API
	 * 
	 * @param clientId unique identifier of your client program
	 * @param privateKey should match the public key registered with this client id
	 */
	public ServerCfg(String clientId, PrivateKey privateKey) {
		super();
		this.clientId = clientId;
		this.privateKey = privateKey;
	}

	/**
	 * Constructor
	 * 
	 * allows use of non-default REST API location
	 * 
	 * @param rootUri uri to REST API. For example, https://beta-rest.smartvault.com/
	 * @param clientId unique identifier of your client program
	 * @param key should match the public key registered with this client id
	 */
	public ServerCfg(String rootUri, String clientId, PrivateKey key) {
		super(rootUri);
		this.clientId = clientId;
		this.privateKey = key;
	}

	/**
	 * 
	 * @return unique identifier of your client program
	 */
	public String getClientId() {
		return this.clientId;
	}

	/**
	 * 
	 * @return the private key for your client program
	 */
	public PrivateKey getPrivateKey() {
		return this.privateKey;
	}
}